@@ -10,12 +10,21 @@ case "$opt:$systype" in
   pentium:*)
     echo pentium
     ;;
+  ppro:*)
+    echo ppro
+    ;;
   sparc:*)
     echo sparc
     ;;
-  auto:*:i386-*:*:*:*)
+  auto:*:*:*:genuineintel-?????5*:*)
     echo pentium
     ;;
+  auto:*:*:*:genuineintel-*:*)
+    echo ppro
+    ;;
+  auto:*:i386-*:*:*:*)
+    echo ppro
+    ;;
   *)
     echo sparc
     ;;
